@@ -26,6 +26,12 @@ import subprocess
 import re
 import zlib
 import lzma
+
+try:
+    import numpy as np
+    
+except (ModuleNotFoundError, ImportError):
+    pass
     
 try:
     import PIL
@@ -217,13 +223,16 @@ except (ModuleNotFoundError, ImportError):
     except NameError:
         raise ModuleError("setuptools and Cython must be installed. Try `pip install setuptools Cython` or `pip install beetroot[cython]`.")
 
-def printn(str_:"string to print"=""):
+def printn(*args):
     """Prints a string without a trailing newline"""
-    if objtype(str_) == "bytes":
-        print(str_.decode("iso-8859-1"), end="", flush=True)
-        
-    else:
-        print(str(str_), end="", flush=True)
+    for i in range(0, len(args)):
+        if objtype(args[i]) == "bytes":
+            args[i] = str(args[i].decode("iso-8859-1"))
+            
+        else:
+            args[i] = str(args[i])
+            
+    print(" ".join(args))
         
     return 0
 
@@ -276,6 +285,10 @@ def test() -> "Hello, world!":
     print("Hello, world!")
     return 0
 
+def locate():
+    """I literally made this cuz I was tired of looking for my python folder."""
+    assert 1 > 2
+
 def remove(str_:"a string", ting:"also a string"):
     """Removes all occurences of "ting" in str_"""
     return str_.replace(str(ting), "")
@@ -294,12 +307,25 @@ def siteize(str_:"a string"):
     b = remove("".join(b).title(), " ")
     return "".join(["www.", b, ".com"])
     
-def taskkill(tasque):
+def taskkill(tasque, **kwargs):
     """Kills a task by name with psutil."""
     try:
+        ka = int(
+            kwargs.get(
+                "killamount",
+                None
+            )
+        )
         for proc in psutil.process_iter():
             if proc.name() == tasque:
                 proc.kill()
+                if ka == None:
+                    pass
+                
+                else:
+                    ka -= 1
+                    if ka <= 0:
+                        return 0
                 
     except NameError:
         raise ModuleError("psutil must be installed to use beetroot.taskkill(). Use pip install psutil or pip install beetroot[ram].")
@@ -315,30 +341,90 @@ def crash() -> "Crashes python or smth idk":
     
     return 1
     
-def quicksort(array) -> "Sorted array":
+def quicksort(array:"Unsorted array") -> "Sorted array":
     """Quicksort algorithm"""
+    try:
+        with recursion(1500):
+            less = []
+            equal = []
+            greater = []
 
-    less = []
-    equal = []
-    greater = []
-
-    if len(array) > 1:
-        pivot = array[0]
+            if len(array) > 1:
+                pivot = array[0]
+                
+                for x in array:
+                    if x < pivot:
+                        less.append(x)
+                        
+                    elif x == pivot:
+                        equal.append(x)
+                        
+                    elif x > pivot:
+                        greater.append(x)
+                        
+                return quicksort(less) + equal + quicksort(greater)
+            
+            else:
+                return array
         
-        for x in array:
-            if x < pivot:
-                less.append(x)
-                
-            elif x == pivot:
-                equal.append(x)
-                
-            elif x > pivot:
-                greater.append(x)
-                
-        return quicksort(less) + equal + quicksort(greater)
+    except TypeError:
+        raise InvalidTypeError(f"Cannot sort type {objtype(array)}.")
     
-    else:
+def cyclesort(array:"Unsorted Array") -> "Sorted Array":
+    """Cyclesort, much slower than quicksort but uses less RAM"""
+    try:
+        for cycleStart in range(0, len(array) - 1):
+            item = array[cycleStart]
+            pos = cycleStart
+            
+            for i in range(cycleStart + 1, len(array)):
+                if array[i] < item:
+                    pos += 1
+                
+            if pos == cycleStart:
+                continue
+            
+            while item == array[pos]:
+                pos += 1
+             
+            array[pos], item = item, array[pos]
+          
+            while pos != cycleStart:
+                pos = cycleStart
+             
+                for i in range(cycleStart + 1, len(array)):
+                    if array[i] < item:
+                        pos += 1
+                   
+                while item == array[pos]:
+                    pos += 1
+                
+                array[pos], item = item, array[pos]
+             
         return array
+    
+    except TypeError:
+        raise InvalidTypeError(f"Cannot sort type {objtype(array)}.")
+
+def swap(array, ia, ib):
+    array[ia], array[ib] = array[ib], array[ia]
+    return array
+
+def strlist(args):
+    for i in range(0, len(args)):
+        if objtype(args[i]) == "bytes":
+            args[i] = args[i].decode("iso-8859-1")
+            
+        else:
+            args[i] = str(args[i])
+            
+    return args
+
+def errprint(*args):
+    sys.stderr.write(" ".join(strlist(list(args))) + "\n")
+    
+def errprintn(*args):
+    sys.stderr.write(" ".join(strlist(list(args))))
 
 def execfile(file:"a filepath to a .py file"):
     """Executes a python .py script"""
